Qiscus API Wrapper
==================

Python wrapper for Qiscus SDK [RESTful API](https://www.qiscus.com/docs/restapi). This wrapper allows Qiscus user to manage users, comments, and rooms in Qiscus app. 

## Installation

```python
pip install qiscusapi
```
## Requires
* [requests](https://pypi.python.org/pypi/requests) - Python HTTP for Humans.

## Usage
Initialize the API with your `app_id` and `qiscus_secret_key`:
```python
import qiscusapi
api = qiscusapi.api.Api('app_id', 'qiscus_secret_key')
```
Now, you can use available methods:
```python
r = api.login_or_register('your_email', 'your_username', 'your_password'):
print(r.user_id, r.user_email, r.username, r.user_avatar_url, r.user_token)

r = api.get_user_room_lists('user_email')
for rooms in r.rooms_info:
    print(rooms.room_name)
```
## Lists of methods
This is lists of available method in this wrapper. You can also access [docstring](https://www.python.org/dev/peps/pep-0257/) for specific methods. Example:
```python
help(get_user_room_lists)
```

login_or_register:

```python
Accepted parameters:

email [string]
password [string password, optional] # password will be updated if user already exist
username [string]
avatar_url [string url, optional]
device_token [string, optional]
device_platform ["ios" or "android", optional]
```

get_user_profile:
```python
Accepted parameters:

user_email [string]
```

get_user_room_lists:
```python
Accepted parameters:

user_email [string] required
page [int, optional] number of page
show_participants [bool, optional] "true" or "false" default will be false
room_type [string, optional] filter by room type ("single" or "group") default will be return all type
```

create_room:
```python
Accepted parameters:

name [string]
creator [string email]
participants[] [array of string email]
avatar_url [string] optional
```

update_room:
```python
Accepted parameters:

user_email [string required] must one of user participant
room_id [string required] must be group room
room_name [string optional]
room_avatar_url [string optional]
options [string optional]
```

get_or_create_room_with_target:
```python
Accepted parameters:

email1 [string required]
email2 [string required]
```

get_rooms_info:
```python
Accepted parameters:

user_email [string email]
room_id[] [array of string]
show_participants [boolean true or false, default is false]
```

add_room_participants:
```python
Accepted parameters:

room_id [string]
emails[] [array of string emails]
```

remove_room_participants:
```python
Accepted parameters:

room_id [string]
emails [array of string emails]
```

post_comment_text:
```python
Accepted parameters:

sender_email [string]
room_id [string], it can be room_id or channel id specified by client or auto generated by server
message [string]
payload [string json, see payload definitions bellow]
unique_temp_id [string, optional, default=generated by backend]
disable_link_preview [bool, optional, default=false]
```
post_comment_buttons:
```python
Accepted parameters:

sender_email [string]
room_id [string], it can be room_id or channel id specified by client or auto generated by server
payload [string json, see payload definitions bellow]
```

post_comment_card:
```python
Accepted parameters:

sender_email [string]
room_id [string], it can be room_id or channel id specified by client or auto generated by server
payload [string json, see payload definitions bellow]
```

post_comment_postback_button:
```python
Accepted parameters:

sender_email [string]
room_id [string], it can be room_id or channel id specified by client or auto generated by server
payload [string json, see payload definitions bellow]
```

post_comment_account_linking:
```python
Accepted parameters:

sender_email [string]
room_id [string], it can be room_id or channel id specified by client or auto generated by server
payload [string json, see payload definitions bellow]
```

post_comment_custom:
```python
Accepted parameters:

sender_email [string]
room_id [string], it can be room_id or channel id specified by client or auto generated by server
payload [string json, see payload definitions bellow]
```

load_comments:
```python
Accepted parameters:

room_id [string]
page [int optional]
limit [int optional default=20]
```


## Further Information
For more information, please check RESTful API Qiscus [documentation](https://www.qiscus.com/docs/restapi)